@@ -3,14 +3,15 @@ Main interface for serverlessrepo service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.serverlessrepo import (
+    from mypy_boto3_serverlessrepo import (
         Client,
         ListApplicationDependenciesPaginator,
         ListApplicationVersionsPaginator,
         ListApplicationsPaginator,
         ServerlessApplicationRepositoryClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,17 +21,17 @@ Usage::
     list_application_dependencies_paginator: ListApplicationDependenciesPaginator = client.get_paginator("list_application_dependencies")
     list_application_versions_paginator: ListApplicationVersionsPaginator = client.get_paginator("list_application_versions")
     list_applications_paginator: ListApplicationsPaginator = client.get_paginator("list_applications")
+    ```
 """
-from mypy_boto3_serverlessrepo.client import (
-    ServerlessApplicationRepositoryClient,
-    ServerlessApplicationRepositoryClient as Client,
-)
+from mypy_boto3_serverlessrepo.client import ServerlessApplicationRepositoryClient
 from mypy_boto3_serverlessrepo.paginator import (
     ListApplicationDependenciesPaginator,
-    ListApplicationVersionsPaginator,
     ListApplicationsPaginator,
+    ListApplicationVersionsPaginator,
 )
 
+Client = ServerlessApplicationRepositoryClient
+
 
 __all__ = (
     "Client",
